import { select, 
        csv, 
        scaleTime, 
        max, 
        scaleBand, 
        scaleOrdinal,
        axisLeft, 
        axisBottom } from 'd3';

const svg = select('svg');

const height = +svg.attr('height');
const width = +svg.attr('width');

const render = data => {
	const xValue = d => d.population;
	const yValue = d => d.country;
  const startDate = new Date(2016,10,06);
  
  const days = [1, 5, 10, 3, 18, 4, 6, 4, 5];
  
  const dates = days => {
      var ds = [];      
      var nextDay = new Date(startDate);  
        
      days.forEach(function(value){       
          nextDay.setDate(nextDay.getDate()+value);	
        ds.push(new Date(nextDay));
      });
        
      return ds;
    };
  
  const margin = {
    top: 20,
    right: 20,
    bottom: 20,
    left: 20
  }
  const innerwidth = width - margin.left - margin.right;
  const innerheight = height - margin.top - margin.bottom;

  const xScale = scaleTime()    
    .domain([new Date(2016, 10, 06), new Date(2017, 1, 28)])
	  .range([0,innerwidth])
    .nice();
  
  const yScale = scaleBand()  	
    .rangeRound([0, innerheight])
    .paddingInner(0.1)
    .align(0.1);
  
  const zScale = scaleOrdinal()
    .range(["#98abc5", "#8a89a6", "#7b6888", "#6b486b", "#a05d56", "#d0743c", "#ff8c00"]);
  
  const yAxis = axisLeft(yScale);
    

  const g = svg.append('g')
		.attr('transform', `translate(${margin.left}, ${margin.top})`);
  
  g.append('g').call(axisLeft(yScale));
  g.append('g').call(axisBottom(xScale))
  	.attr('transform', `translate(0, ${innerheight})`);
  
  g.selectAll('rect').data(data)
     .enter().append('rect')
        .attr('y', d=> yScale(yValue(d)))
      	.attr('width', d => xScale(d.population))
        .attr('height', yScale.bandwidth());
};

csv('data.csv').then(data => {
  data.forEach(d => {
    d.population = +d.population;
  });
  render(data);
});